@@ -20,7 +20,7 @@ use crate::{
 use super::world_socket::WriterMessage;
 
 #[async_trait]
-pub trait WorldSessionI<T> {
+pub trait WorldSession<T> {
     /// On Connection Open
     async fn on_open(socket_tools: SocketTools, world: &'static T) -> Result<Arc<Self>, Error>;
     fn socket_tools(&self) -> &SocketTools;
@@ -52,7 +52,7 @@ impl SocketTools {
         }
     }
 
-    pub fn send(&self, cmd: u16, payload: Option<impl AsRef<[u8]>>) {
+    pub fn send(&self, cmd: u16, payload: Option<&[u8]>) {
         if !self.is_closed() {
             if let Ok(bytes) = to_bytes(cmd, payload) {
                 if let Err(error) = self.tx.send(WriterMessage::Bytes(bytes.freeze())) {
